Version 6.0～7.0
=================

Version6.0～7.0までのリリースノートです。

## :package: 6.0.1

:fontawesome-solid-calendar: `2025-09-27`

!!! note "セキュリティアップデート"

## :package: 6.0.0

:fontawesome-solid-calendar: `2025-01-04`

!!! info "Python3.13をサポートするようになりました"

!!! danger "Python3.8のサポートを終了しました"

!!! note "セキュリティアップデート"

!!! note "Poetryの代わりにuvを使用するようにしました"

